/*
    control++ : System configuration tool
    Copyright (C) 2017-2024 Alexey Appolonov

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef controllerH
#define controllerH

#include "main.h"
#include "unit.h"
#include "ulimits.h"
#include "perms.h"
#include "starter.h"

#define UNITS_Q             3   // Number of control units
#define U_ULIMITS           0   // ULimits control unit id
#define U_PERMS             1   // Permissions control unit id
#define U_SCRIPTS           2   // Script Starter control unit id

#define EXTERNAL_CONF       0   // Index of the conf file that user can change
#define INTERNAL_CONF       1   // Index of the conf file that user
                                //      should not change

#define MICRO_MODES_SECNAME     "micro_modes"
#define INTERNAL_CONF_HEADER    "# Do not change this file!"

//-----------------------------------------------------------------------------
// Main interface

class TController : public TUnit{

    private:

        array<TUnit*, UNITS_Q> units;       // Controlled units
        vector<TUnit*> units_of_the_mode;   // Controlled units involved
                                            // in the current mode setting
        // Get previous mode of the unit
        string PrevSubMode(const string& unit_name);
        // Find unit by it's keyword and return the pointer
        TUnit* GetUnit(const string& unit_name);
        // Drop every DOM section but leave section that stores micro modes
        void ClearEveryDOMSecButMicroModeSec(void);
        // Clear internal configuration file
        bool WipeCurrentMode(const string &unit_name="");
        // Save mode to the internal configuration file
        bool SaveCurrentMode(const string &new_mode, const string &unit_name="");

    public:

        // Display content of configuration file
        bool PrintConfFile(void);
        // Display current mode for all units
        void PrintCurrentModesOfTheUnits(void);
        // Apply configuration file DOM to the unit
        bool ApplyConfDOM(void);
        // Form vector of names of the available modes
        bool FindoutAvailableModes(void);
        // Controller has nothing to apply
        bool ApplyMode(const string &mode_name, const string &prev_mode=""){
            return true;
            }
        // Check controversy between internal and external config files
        bool ConfigsControversy(void);
        // Check mode compliance
        bool CheckModeCompliance(string mode_name, const string &unit_name);
        bool CheckModeCompliance(const string &mode_name){
            return CheckModeCompliance(mode_name, "");
            }   // - definition of this function is required by the parent class
        // Set given mode
        bool SetMode(const string &mode_name, const string &unit_name="");
        // Print available macro modes and available modes of all the units
        void PrintAvailableMacroAndMicroModes(void);

        TController(void);
        ~TController(void);
    };

//-----------------------------------------------------------------------------

#endif
