/*
    control++ : System configuration tool
    Copyright (C) 2017-2024 Alexey Appolonov

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef mainH
#define mainH

//#define DEBUGING

#ifdef DEBUGING
#define BUILDROOT_DIR   ""
#define CONF_DIR        "/home/alexey/devel/control++/samples/"
    // Catalog with all control++ configuration files
#define STATE_DIR       CONF_DIR "states/"
    // Catalog where all the hid files are stored (internal conf and reset files)
#define SECURITY_DIR    CONF_DIR "limits.d/"
    // Catalog with system ulimits
#include "libcontrol++.h"
#include "print.h"
#include "special.h"
#else
#define BUILDROOT_DIR   "/usr/src/tmp/control++-buildroot/"
#define CONF_DIR        "/etc/control++/"
    // Catalog with all control++ configuration files
#define STATE_DIR      "/var/lib/control++/"
    // Catalog where all the hid files are stored (internal conf and reset files)
#define SECURITY_DIR    "/etc/security/limits.d/"
    // Catalog with system ulimits
#include <libcontrol++/libcontrol++.h>
#include <libcontrol++/print.h>
#include <libcontrol++/special.h>
#endif

#define MAIN_CONF_FILE  CONF_DIR "control++.conf"
    // Control++ configuration file
#define INTERNAL_CONF_FILE  STATE_DIR ".current_mode.conf"
    // Internal control++ configuration file (that user should not modify)
#define RESET_MODE      ".reset"
    // Name of the mode that will reset (drop) the current mode
#define SECURITY_LIM    "control++.conf"
    // Right part of the filename of the control++ active ulimits
#define UNKNOWN_MODE    "???"
    // Label of the unkmown mode

#define M_NON_UNIQUE_PERM       0   // Index of the '--uniq' run-mode flag
#define M_VERBOSE               1   // ... '--verbose' run-mode flag
#define M_SILENT_TERMINATION    2   // ... silent termination of the program
#define M_MICRO_MODESETTING     3   // ... micro modesetting in progress
#define M_RUNNING_IN_BUILD_ENV  4   // ... running in build-environment

using namespace std;

//-----------------------------------------------------------------------------

extern TRunMode run_mode;   // Set of run-params of the program
extern TPrinter printer;    // Printer of the complex messages

//-----------------------------------------------------------------------------

const string EnvPath(const string &path);

#endif
