/*
    control++ : System configuration tool
    Copyright (C) 2017-2024 Alexey Appolonov

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef permsH
#define permsH

#include "main.h"
#include "unit.h"

#ifdef DEBUGING
#include "permissions.h"
#include "permissions_group_mode.h"
#else
#include <libcontrol++/permissions.h>
#include <libcontrol++/permissions_group_mode.h>
#endif

#define RECURSIVE       true        // Recursive dir following
#define NOT_RECURSIVE   false       // No recursive dir following

//-----------------------------------------------------------------------------
// Permissions control unit

// Reads sectors of the conf file into TFileMode objects,
// forms file permissions for a complex sectors like 'dir' or 'list',
// applies permissions stored in the vector of TFileMode objects

class TPermissions : public TUnit{

    private:

        vector<TFileMode*> modes;   // Mass of permissions/acls for the new mode
        vector<TFileMode*> modes0;  // Mass of permissions/acls that was actual
                                    //  before new mode was set
        vector<vector<string>> essentials;  // List of variants of essential
                                    //  applications that should be considered
                                    //  in the whitelist
        TSectorType current_sector; // Current sector in the process of parsing

        TGroupOfFilesMode group_of_files; // Params of the current group of
									//  files (for according section types)

        // Push new file mode to the perms/acls vector
        bool AddFileMode(TFileMode *&new_mode, const bool en_check=false);
        // Add new permissions for the files of the dir
        bool AddDirMode(TFileMode *mode, const vector<string> &exclude,
                bool recursive=false);
        bool AddDirMode(TFileMode *mode, const bool recursive=false){
            return AddDirMode(mode, vector<string>(), recursive);
            }
        // Form permissions/ACl for all files of the list
        bool AddListMode(TFileMode *mode);
        // Disallow execution of every file in '/'
        bool ModeToDisallowExeOfEverything(const string &base_dir,
                const vector<string> &except);
        // Remove repetitions from formed perms and acls
        void UniquifyModes(void);

    public:
        // Apply permissions mode stated in configuration DOM
        bool ApplyConfDOM(void);
        // Get current modes of the files, stated in 'modes' vector
        bool GetCurrentModes(void);
        // Write current permissions into the "reset" file
        bool SaveStateHeldBeforeModeSetting(void);
        // Apply current permission type
        bool ApplyMode(const string &mode_name, const string &prev_mode="");
        // Check permissions compliance for all files
        bool CheckModeCompliance(const string &mode_name);
        // Clear the modes
        void ClearModes(vector<TFileMode*> &m);
        void Clear(void){
            ClearModes(modes);
            ClearModes(modes0);
            }

        TPermissions(void);
        ~TPermissions(void){}
    };

//-----------------------------------------------------------------------------

#endif
