/*
    control++ : System configuration tool
    Copyright (C) 2017-2024 Alexey Appolonov

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef starterH
#define starterH

#include "main.h"
#include "unit.h"

//-----------------------------------------------------------------------------
// Starter control unit

class TStarter : public TUnit{

    private:

        array<string, 3> actions;

        // Form vector of names of the available modes
        void FindoutAvailableModesSpecialPart(dirent *ent, vector<string> &modes);
        // Run script stated in configuration file
        bool RunScript(const string &mode_name, const string &action);

    public:

        // The unit has no config file
        bool Configure(void){
            return true;
            }
        // Run "do" or "undo" or "test" script of the mode
        bool ApplyMode(const string &mode_name, const string &prev_mode="");
        // Check mode compliance
        bool CheckModeCompliance(const string &mode_name);

        TStarter(void){
            keyword = KW_SCRIPTS;
            actions[0] = "do";
            actions[1] = "undo";
            actions[2] = "test";
            }
        ~TStarter(void){}
    };

//-----------------------------------------------------------------------------

#endif
