/*
    control++ : System configuration tool
    Copyright (C) 2017-2024 Alexey Appolonov

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef ulimitsH
#define ulimitsH

#include "main.h"
#include "unit.h"

//-----------------------------------------------------------------------------
// ULimits control unit

class TULimits : public TUnit{

    private:

        // Generate name for the file so it would be read last
        string GenerateFilename(void);
        // Remove control++ limits from the "limits.d" dir
        bool CleanLimitsD(void);
        // Get path of an active conf file
        string ActiveConfPath(void);

    public:

        // The unit has no config file
        bool Configure(void){
            return true;
            }
        // Save current ulimits file to be able to restore it later
        bool SaveStateHeldBeforeModeSetting(void);
        // Copy ulimits file that is appropriate to a current mode
        bool ApplyMode(const string &mode_name, const string &prev_mode="");
        // Check mode compliance
        bool CheckModeCompliance(const string &mode_name);

        TULimits(void){
            keyword = KW_ULIMITS;
            }
        ~TULimits(void){}
    };

//-----------------------------------------------------------------------------

#endif
